@@ -201,11 +201,11 @@ get_timezone_from_ical (GcalEvent             *self,
     }
 
   /*
-   * If tz is NULL, the timezone identifier is invalid. Fallback to UTC
+   * If tz is NULL, the timezone identifier is invalid. Fallback to the local timezone
    * in this case.
    */
   if (!tz)
-    tz = g_time_zone_new_utc ();
+    tz = g_time_zone_new_local ();
 
   GCAL_TRACE_MSG ("%s (%p)", g_time_zone_get_identifier (tz), tz);
 
@@ -234,7 +234,7 @@ build_component_from_datetime (GcalEvent *self,
       g_autoptr (GTimeZone) zone = NULL;
       ICalTimezone *tz;
 
-      zone = gcal_util_get_app_timezone_or_local ();
+      zone = g_date_time_get_timezone (dt);
       tz = gcal_timezone_to_icaltimezone (zone);
       i_cal_time_set_timezone (itt, tz);
       tzid = g_strdup (i_cal_timezone_get_tzid (tz));
@@ -1929,3 +1929,21 @@ gcal_event_format_date (GcalEvent *self)
 
   return g_steal_pointer (&formatted_string);
 }
+
+/**
+ * gcal_event_overlaps:
+ * @self: a #GcalEvent
+ * @range: a #GcalRange
+ *
+ * Returns: True if the event range overlaps the @range
+ */
+gboolean
+gcal_event_overlaps (GcalEvent *self,
+                     GcalRange *range)
+{
+  GcalRangeOverlap overlap;
+
+  g_return_val_if_fail (GCAL_IS_EVENT (self), FALSE);
+  overlap = gcal_range_calculate_overlap (gcal_event_get_range (self), range, NULL);
+  return overlap != GCAL_RANGE_NO_OVERLAP;
+}
