@@ -31,7 +31,7 @@
 
 struct _GcalCalendarsPage
 {
-  AdwBin              parent;
+  AdwNavigationPage   parent;
 
   GtkListBox         *listbox;
   AdwToastOverlay    *toast_overlay;
@@ -47,7 +47,7 @@ static void          on_calendar_color_changed_cb                (GcalCalendar
                                                                   GParamSpec         *pspec,
                                                                   GtkImage           *icon);
 
-G_DEFINE_TYPE_WITH_CODE (GcalCalendarsPage, gcal_calendars_page, ADW_TYPE_BIN,
+G_DEFINE_TYPE_WITH_CODE (GcalCalendarsPage, gcal_calendars_page, ADW_TYPE_NAVIGATION_PAGE,
                          G_IMPLEMENT_INTERFACE (GCAL_TYPE_CALENDAR_MANAGEMENT_PAGE,
                                                 gcal_calendar_management_page_iface_init))
 
@@ -258,8 +258,8 @@ on_listbox_row_activated_cb (GtkListBox        *listbox,
 }
 
 static void
-on_new_calendar_button_clicked_cb (GtkButton         *button,
-                                   GcalCalendarsPage *self)
+on_new_calendar_row_activated_cb (AdwButtonRow      *button,
+                                  GcalCalendarsPage *self)
 {
   GcalCalendarManagementPage *page = GCAL_CALENDAR_MANAGEMENT_PAGE (self);
 
@@ -331,18 +331,6 @@ on_toast_dismissed_cb (AdwToast          *toast,
  * GcalCalendarManagementPage iface
  */
 
-static const gchar*
-gcal_calendars_page_get_name (GcalCalendarManagementPage *page)
-{
-  return "calendars";
-}
-
-static const gchar*
-gcal_calendars_page_get_title (GcalCalendarManagementPage *page)
-{
-  return _("Calendars");
-}
-
 static void
 gcal_calendars_page_activate (GcalCalendarManagementPage *page,
                               GcalCalendar               *calendar)
@@ -365,7 +353,9 @@ gcal_calendars_page_activate (GcalCalendarManagementPage *page,
   remove_calendar (self, calendar);
 
   /* Create the new toast */
-  new_string = g_markup_printf_escaped (_("Calendar <b>%s</b> removed"),
+
+  /* TRANSLATORS: %s is a calendar name. */
+  new_string = g_markup_printf_escaped (_("Calendar “%s” removed"),
                                         gcal_calendar_get_name (calendar));
 
   toast = adw_toast_new (new_string);
@@ -386,8 +376,6 @@ gcal_calendars_page_activate (GcalCalendarManagementPage *page,
 static void
 gcal_calendar_management_page_iface_init (GcalCalendarManagementPageInterface *iface)
 {
-  iface->get_name = gcal_calendars_page_get_name;
-  iface->get_title = gcal_calendars_page_get_title;
   iface->activate = gcal_calendars_page_activate;
 }
 
@@ -477,7 +465,7 @@ gcal_calendars_page_class_init (GcalCalendarsPageClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalCalendarsPage, toast_overlay);
 
   gtk_widget_class_bind_template_callback (widget_class, on_listbox_row_activated_cb);
-  gtk_widget_class_bind_template_callback (widget_class, on_new_calendar_button_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, on_new_calendar_row_activated_cb);
 }
 
 static void
