@@ -26,9 +26,11 @@
 #include "gcal-edit-calendar-page.h"
 #include "gcal-utils.h"
 
+#include <glib/gi18n.h>
+
 struct _GcalEditCalendarPage
 {
-  AdwBin              parent;
+  AdwNavigationPage   parent;
 
   AdwActionRow       *account_row;
   GtkColorDialogButton *calendar_color_button;
@@ -36,7 +38,7 @@ struct _GcalEditCalendarPage
   AdwActionRow       *calendar_url_row;
   AdwSwitchRow       *default_row;
   AdwEntryRow        *name_entry;
-  GtkWidget          *remove_button;
+  GtkWidget          *remove_group;
 
   GcalCalendar       *calendar;
 
@@ -45,7 +47,7 @@ struct _GcalEditCalendarPage
 
 static void          gcal_calendar_management_page_iface_init    (GcalCalendarManagementPageInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (GcalEditCalendarPage, gcal_edit_calendar_page, ADW_TYPE_BIN,
+G_DEFINE_TYPE_WITH_CODE (GcalEditCalendarPage, gcal_edit_calendar_page, ADW_TYPE_NAVIGATION_PAGE,
                          G_IMPLEMENT_INTERFACE (GCAL_TYPE_CALENDAR_MANAGEMENT_PAGE,
                                                 gcal_calendar_management_page_iface_init))
 
@@ -141,8 +143,14 @@ setup_calendar (GcalEditCalendarPage *self,
 
   get_source_parent_name_color (manager, source, &parent_name, NULL);
 
+  GCAL_TRACE_MSG ("Calendar '%s' is GOA: %d; is file: %d; is remote: %d",
+                  gcal_calendar_get_name (calendar),
+                  is_goa,
+                  is_file,
+                  is_remote);
+
   gtk_widget_set_visible (GTK_WIDGET (self->account_row), is_goa);
-  gtk_widget_set_visible (GTK_WIDGET (self->calendar_url_row), !is_goa && (is_file || is_remote));
+  gtk_widget_set_visible (GTK_WIDGET (self->calendar_url_row), !is_goa);
 
   /* If it's a file, set the file path */
   if (is_file)
@@ -158,9 +166,12 @@ setup_calendar (GcalEditCalendarPage *self,
       basename = g_file_get_basename (file);
       uri = g_file_get_uri (file);
 
-      text = g_strdup_printf ("<a href=\"%s\">%s</a>", uri, basename);
+      text = g_strdup_printf ("<a title=\"%1$s\" href=\"%2$s\">%1$s</a>", basename, uri);
       adw_action_row_set_subtitle (self->calendar_url_row, text);
-      gtk_widget_set_tooltip_text (GTK_WIDGET (self->calendar_url_row), basename);
+
+      gtk_accessible_update_property (GTK_ACCESSIBLE (self->calendar_url_row),
+                                      GTK_ACCESSIBLE_PROPERTY_LABEL, basename,
+                                      -1);
     }
 
   /* If it's remote, build the uri */
@@ -174,10 +185,14 @@ setup_calendar (GcalEditCalendarPage *self,
       webdav = e_source_get_extension (source, E_SOURCE_EXTENSION_WEBDAV_BACKEND);
       guri = e_source_webdav_dup_uri (webdav);
       uri = g_uri_to_string_partial (guri, G_URI_HIDE_PASSWORD);
+      text = g_strdup_printf ("<a title=\"%1$s\" href=\"%1$s\">%1$s</a>", uri);
 
-      text = g_strdup_printf ("<a href=\"%s\">%s</a>", uri, uri);
+      adw_preferences_row_set_title (ADW_PREFERENCES_ROW (self->calendar_url_row), _("Calendar URL"));
       adw_action_row_set_subtitle (self->calendar_url_row, text);
-      gtk_widget_set_tooltip_text (GTK_WIDGET (self->calendar_url_row), uri);
+
+      gtk_accessible_update_property (GTK_ACCESSIBLE (self->calendar_url_row),
+                                      GTK_ACCESSIBLE_PROPERTY_LABEL, uri,
+                                      -1);
     }
 
   if (is_goa)
@@ -188,13 +203,19 @@ setup_calendar (GcalEditCalendarPage *self,
       adw_action_row_set_subtitle (self->account_row, name);
     }
 
+  if (!is_goa && !is_remote && !is_file)
+    {
+      adw_preferences_row_set_title (ADW_PREFERENCES_ROW (self->calendar_url_row), _("Location"));
+      adw_action_row_set_subtitle (self->calendar_url_row, _("On This Computer"));
+    }
+
   gtk_color_dialog_button_set_rgba (self->calendar_color_button, gcal_calendar_get_color (calendar));
   gtk_editable_set_text (GTK_EDITABLE (self->name_entry), gcal_calendar_get_name (calendar));
   adw_switch_row_set_active (self->calendar_visible_row, gcal_calendar_get_visible (calendar));
 
   adw_switch_row_set_active (self->default_row, source == default_source);
   gtk_widget_set_visible (GTK_WIDGET (self->default_row), !gcal_calendar_is_read_only (calendar));
-  gtk_widget_set_visible (self->remove_button, e_source_get_removable (source));
+  gtk_widget_set_visible (self->remove_group, e_source_get_removable (source));
 }
 
 static void
@@ -226,8 +247,8 @@ update_calendar (GcalEditCalendarPage *self)
  */
 
 static void
-on_remove_button_clicked_cb (GtkButton            *button,
-                             GcalEditCalendarPage *self)
+on_remove_button_row_activated_cb (GtkButton            *button,
+                                   GcalEditCalendarPage *self)
 {
   GcalCalendarManagementPage *page;
 
@@ -271,20 +292,6 @@ on_settings_button_clicked_cb (GtkWidget            *button,
  * GcalCalendarManagementPage iface
  */
 
-static const gchar*
-gcal_edit_calendar_page_get_name (GcalCalendarManagementPage *page)
-{
-  return "edit-calendar";
-}
-
-static const gchar*
-gcal_edit_calendar_page_get_title (GcalCalendarManagementPage *page)
-{
-  GcalEditCalendarPage *self = GCAL_EDIT_CALENDAR_PAGE (page);
-
-  return self->calendar ? gcal_calendar_get_name (self->calendar) : "";
-}
-
 static void
 gcal_edit_calendar_page_activate (GcalCalendarManagementPage *page,
                                   GcalCalendar               *calendar)
@@ -319,8 +326,6 @@ gcal_edit_calendar_page_deactivate (GcalCalendarManagementPage *page)
 static void
 gcal_calendar_management_page_iface_init (GcalCalendarManagementPageInterface *iface)
 {
-  iface->get_name = gcal_edit_calendar_page_get_name;
-  iface->get_title = gcal_edit_calendar_page_get_title;
   iface->activate = gcal_edit_calendar_page_activate;
   iface->deactivate = gcal_edit_calendar_page_deactivate;
 }
@@ -400,9 +405,9 @@ gcal_edit_calendar_page_class_init (GcalEditCalendarPageClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, calendar_visible_row);
   gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, default_row);
   gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, name_entry);
-  gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, remove_button);
+  gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, remove_group);
 
-  gtk_widget_class_bind_template_callback (widget_class, on_remove_button_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, on_remove_button_row_activated_cb);
   gtk_widget_class_bind_template_callback (widget_class, on_settings_button_clicked_cb);
 }
 
