@@ -36,6 +36,7 @@ struct _GcalRemindersSection
   GtkWidget          *alarms_popover;
   GtkListBoxRow      *new_alarm_row;
 
+  GtkWidget          *event_start_button;
   GtkWidget          *five_minutes_button;
   GtkWidget          *ten_minutes_button;
   GtkWidget          *fifteen_minutes_button;
@@ -57,6 +58,8 @@ static void          gcal_event_editor_section_iface_init        (GcalEventEdito
 static void          on_remove_alarm_cb                          (GcalAlarmRow         *alarm_row,
                                                                   GcalRemindersSection *self);
 
+static void          on_update_alarm_cb                          (GcalAlarmRow         *alarm_row,
+                                                                  GcalRemindersSection *self);
 
 G_DEFINE_TYPE_WITH_CODE (GcalRemindersSection, gcal_reminders_section, GTK_TYPE_BOX,
                          G_IMPLEMENT_INTERFACE (GCAL_TYPE_EVENT_EDITOR_SECTION, gcal_event_editor_section_iface_init))
@@ -80,6 +83,7 @@ struct
   gint minutes;
   gint button_offset;
 } minutes_button[] = {
+    { 0,     OFFSET (event_start_button) },
     { 5,     OFFSET (five_minutes_button) },
     { 10,    OFFSET (ten_minutes_button) },
     { 15,    OFFSET (fifteen_minutes_button) },
@@ -124,11 +128,22 @@ create_alarm (guint minutes)
 
   alarm = e_cal_component_alarm_new ();
   e_cal_component_alarm_take_trigger (alarm, trigger);
-  e_cal_component_alarm_set_action (alarm, E_CAL_COMPONENT_ALARM_DISPLAY);
+  e_cal_component_alarm_set_action (alarm, E_CAL_COMPONENT_ALARM_AUDIO);
 
   return alarm;
 }
 
+static void
+update_new_alarm_icon (GcalRemindersSection *self)
+{
+  GtkListBoxRow *first_row = gtk_list_box_get_row_at_index (self->alarms_listbox, 0);
+
+  if (first_row == GTK_LIST_BOX_ROW (self->new_alarm_row))
+    adw_button_row_set_start_icon_name (ADW_BUTTON_ROW (self->new_alarm_row), "add-reminder-symbolic");
+  else
+    adw_button_row_set_start_icon_name (ADW_BUTTON_ROW (self->new_alarm_row), "list-add-symbolic");
+}
+
 static void
 clear_alarms (GcalRemindersSection *self)
 {
@@ -146,6 +161,8 @@ clear_alarms (GcalRemindersSection *self)
 
       child = next;
     }
+
+  update_new_alarm_icon (self);
 }
 
 static GtkWidget *
@@ -156,6 +173,7 @@ create_alarm_row (GcalRemindersSection *self,
 
   row = gcal_alarm_row_new (alarm);
   g_signal_connect_object (row, "remove-alarm", G_CALLBACK (on_remove_alarm_cb), self, 0);
+  g_signal_connect_object (row, "update-alarm", G_CALLBACK (on_update_alarm_cb), self, 0);
 
   return row;
 }
@@ -207,6 +225,8 @@ setup_alarms (GcalRemindersSection *self)
       gtk_list_box_append (self->alarms_listbox, row);
     }
 
+  update_new_alarm_icon (self);
+
   GCAL_EXIT;
 }
 
@@ -242,6 +262,38 @@ sort_alarms_func (GtkListBoxRow *a,
   return minutes_a - minutes_b;
 }
 
+static void
+on_update_alarm_cb (GcalAlarmRow         *alarm_row,
+                    GcalRemindersSection *self)
+{
+  ECalComponentAlarm *alarm;
+  gint trigger_minutes;
+  gsize i;
+
+  GCAL_ENTRY;
+
+  alarm = gcal_alarm_row_get_alarm (alarm_row);
+  trigger_minutes = get_alarm_trigger_minutes (self->event, alarm);
+
+  /* Remove from the array */
+  for (i = 0; i < self->alarms->len; i++)
+    {
+      ECalComponentAlarm *a = g_ptr_array_index (self->alarms, i);
+
+      if (trigger_minutes == get_alarm_trigger_minutes (self->event, a))
+        {
+          GCAL_TRACE_MSG ("Updated alarm for %d minutes", trigger_minutes);
+
+          g_ptr_array_remove_index (self->alarms, i);
+          g_ptr_array_insert (self->alarms, i, e_cal_component_alarm_copy (alarm));
+
+          break;
+        }
+    }
+
+  GCAL_EXIT;
+}
+
 static void
 on_remove_alarm_cb (GcalAlarmRow         *alarm_row,
                     GcalRemindersSection *self)
@@ -278,6 +330,8 @@ on_remove_alarm_cb (GcalAlarmRow         *alarm_row,
 
   gtk_list_box_remove (self->alarms_listbox, GTK_WIDGET (alarm_row));
 
+  update_new_alarm_icon (self);
+
   GCAL_EXIT;
 }
 
@@ -290,7 +344,7 @@ on_add_alarm_button_clicked_cb (GtkWidget            *button,
   guint i, minutes;
 
   /* Search for the button minute */
-  minutes = 0;
+  minutes = G_MAXUINT;
 
   for (i = 0; i < G_N_ELEMENTS (minutes_button); i++)
     {
@@ -301,7 +355,7 @@ on_add_alarm_button_clicked_cb (GtkWidget            *button,
         }
     }
 
-  if (minutes == 0)
+  if (minutes == G_MAXUINT)
     return;
 
   alarm = create_alarm (minutes);
@@ -312,6 +366,8 @@ on_add_alarm_button_clicked_cb (GtkWidget            *button,
   g_ptr_array_add (self->alarms, alarm);
 
   gtk_widget_set_sensitive (button, FALSE);
+
+  update_new_alarm_icon (self);
 }
 
 static void
@@ -373,7 +429,7 @@ gcal_reminders_section_changed (GcalEventEditorSection *section)
 
   alarms = gcal_event_get_alarms (self->event);
   if (g_list_length (alarms) != self->alarms->len)
-    GCAL_RETURN (FALSE);
+    GCAL_RETURN (TRUE);
 
   for (GList *l = alarms; l != NULL; l = l->next)
     {
@@ -390,6 +446,10 @@ gcal_reminders_section_changed (GcalEventEditorSection *section)
           if (get_alarm_trigger_minutes (self->event, alarm) == get_alarm_trigger_minutes (self->event, aux))
             {
               other_alarm = aux;
+
+              if (e_cal_component_alarm_get_action (alarm) != e_cal_component_alarm_get_action (aux))
+                GCAL_RETURN (TRUE);
+
               break;
             }
         }
@@ -494,6 +554,7 @@ gcal_reminders_section_class_init (GcalRemindersSectionClass *klass)
 
   gtk_widget_class_bind_template_child (widget_class, GcalRemindersSection, alarms_listbox);
   gtk_widget_class_bind_template_child (widget_class, GcalRemindersSection, alarms_popover);
+  gtk_widget_class_bind_template_child (widget_class, GcalRemindersSection, event_start_button);
   gtk_widget_class_bind_template_child (widget_class, GcalRemindersSection, five_minutes_button);
   gtk_widget_class_bind_template_child (widget_class, GcalRemindersSection, new_alarm_row);
   gtk_widget_class_bind_template_child (widget_class, GcalRemindersSection, one_day_button);
