@@ -201,11 +201,12 @@ manage_weather_service (GcalWeatherSettings *self)
             g_warning ("Unknown location '%s' selected", gtk_editable_get_text (self->weather_location_entry));
         }
 
-      gcal_weather_service_run (weather_service, location);
+      gcal_weather_service_set_location (weather_service, location);
+      gcal_weather_service_activate (weather_service);
     }
   else
     {
-      gcal_weather_service_stop (weather_service);
+      gcal_weather_service_deactivate (weather_service);
     }
 
   GCAL_EXIT;
