@@ -146,9 +146,6 @@ struct _GcalWindow
 
   AdwToast           *delete_event_toast;
 
-  /* calendar management */
-  GtkWidget          *calendar_management_dialog;
-
   gint                open_edit_dialog_timeout_id;
 
   /* weather management */
@@ -279,25 +276,19 @@ update_active_date (GcalWindow *window,
 static void
 recalculate_calendar_colors_css (GcalWindow *self)
 {
-  g_autoptr (GError) error = NULL;
+  g_autoptr (GString) css_colors = NULL;
   g_autoptr (GList) calendars = NULL;
-  g_autofree gchar *new_css_data = NULL;
-  g_auto (GStrv) new_css_snippets = NULL;
   GcalManager *manager;
-  GQuark color_id;
-  GList *l;
-  gint arr_length;
-  gint i = 0;
 
+  css_colors = g_string_new (NULL);
   manager = gcal_context_get_manager (self->context);
   calendars = gcal_manager_get_calendars (manager);
-  arr_length = g_list_length (calendars);
-  new_css_snippets = g_new0 (gchar*, arr_length + 2);
-  for (l = calendars; l; l = l->next, i++)
+  for (GList *l = calendars; l; l = l->next)
     {
       g_autofree gchar* color_str = NULL;
       const GdkRGBA *color;
       GcalCalendar *calendar;
+      GQuark color_id;
 
       calendar = GCAL_CALENDAR (l->data);
 
@@ -305,14 +296,10 @@ recalculate_calendar_colors_css (GcalWindow *self)
       color_str = gdk_rgba_to_string (color);
       color_id = g_quark_from_string (color_str);
 
-      new_css_snippets[i] = g_strdup_printf (".color-%u { --event-bg-color: %s; }", color_id, color_str);
+      g_string_append_printf (css_colors, ".color-%u { --event-bg-color: %s; }\n", color_id, color_str);
     }
 
-  new_css_data = g_strjoinv ("\n", new_css_snippets);
-  gtk_css_provider_load_from_string (self->colors_provider, new_css_data);
-
-  if (error)
-    g_warning ("Error creating custom stylesheet. %s", error->message);
+  gtk_css_provider_load_from_string (self->colors_provider, css_colors->str);
 }
 
 static void
@@ -442,8 +429,9 @@ on_show_calendars_action_activated (GSimpleAction *action,
                                     gpointer       user_data)
 {
   GcalWindow *self = GCAL_WINDOW (user_data);
+  GcalCalendarManagementDialog *dialog = gcal_calendar_management_dialog_new (self->context);
 
-  adw_dialog_present (ADW_DIALOG (self->calendar_management_dialog), GTK_WIDGET (self));
+  adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (self));
 }
 
 static void
@@ -502,11 +490,10 @@ on_window_new_event_cb (GSimpleAction *action,
   GcalEvent *event;
 
   self = GCAL_WINDOW (user_data);
-  start = g_date_time_new (gcal_context_get_timezone (self->context),
-                           g_date_time_get_year (self->active_date),
-                           g_date_time_get_month (self->active_date),
-                           g_date_time_get_day_of_month (self->active_date),
-                           0, 0, 0);
+  start = g_date_time_new_utc (g_date_time_get_year (self->active_date),
+                               g_date_time_get_month (self->active_date),
+                               g_date_time_get_day_of_month (self->active_date),
+                               0, 0, 0);
   end = g_date_time_add_days (start, 1);
 
   manager = gcal_context_get_manager (self->context);
@@ -1062,7 +1049,6 @@ gcal_window_constructed (GObject *object)
    */
   g_object_bind_property (self, "context", self->calendars_button, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->weather_settings, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
-  g_object_bind_property (self, "context", self->calendar_management_dialog, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->week_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->month_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->agenda_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
@@ -1197,7 +1183,6 @@ gcal_window_class_init (GcalWindowClass *klass)
   GtkWidgetClass *widget_class;
 
   g_type_ensure (GCAL_TYPE_AGENDA_VIEW);
-  g_type_ensure (GCAL_TYPE_CALENDAR_MANAGEMENT_DIALOG);
   g_type_ensure (GCAL_TYPE_CALENDAR_BUTTON);
   g_type_ensure (GCAL_TYPE_DATE_CHOOSER);
   g_type_ensure (GCAL_TYPE_EVENT_EDITOR_DIALOG);
@@ -1261,7 +1246,6 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, month_view);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, action_bar);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, quick_add_popover);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, calendar_management_dialog);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, overlay);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, sidebar_toolbar_end);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, split_view);
