@@ -22,12 +22,15 @@
 
 #include <adwaita.h>
 
+#include "gcal-context.h"
+
 G_BEGIN_DECLS
 
 #define GCAL_TYPE_IMPORT_FILE_ROW (gcal_import_file_row_get_type())
 G_DECLARE_FINAL_TYPE (GcalImportFileRow, gcal_import_file_row, GCAL, IMPORT_FILE_ROW, AdwBin)
 
-GtkWidget*           gcal_import_file_row_new                    (GFile              *file,
+GtkWidget*           gcal_import_file_row_new                    (GcalContext        *context,
+                                                                  GFile              *file,
                                                                   GtkSizeGroup       *title_sizegroup);
 
 GPtrArray*           gcal_import_file_row_get_ical_components    (GcalImportFileRow  *self);
