@@ -23,6 +23,7 @@
 #include "gcal-clock.h"
 #include "gcal-context.h"
 #include "gcal-debug.h"
+#include "gcal-gui-utils.h"
 #include "gcal-week-grid.h"
 #include "gcal-week-view.h"
 #include "gcal-week-view-common.h"
@@ -64,9 +65,16 @@ struct _GcalWeekGrid
    * These fields are "cells" rather than minutes. Each cell
    * correspond to 30 minutes.
    */
-  gint                selection_start;
-  gint                selection_end;
-  gint                dnd_cell;
+  struct {
+    gint              start;
+    gint              end;
+    GtkWidget        *widget;
+  } selection;
+
+  struct {
+    gint              cell;
+    GtkWidget        *widget;
+  } dnd;
 
   GcalContext        *context;
 };
@@ -197,16 +205,19 @@ on_click_gesture_pressed_cb (GtkGestureClick *click_gesture,
   gint column;
   gint minute;
 
+  g_assert (self->selection.start == -1);
+  g_assert (self->selection.end == -1);
+
   minute_height = (gdouble) gtk_widget_get_height (GTK_WIDGET (self)) / MINUTES_PER_DAY;
   column_width = floor (gtk_widget_get_width (GTK_WIDGET (self)) / 7);
   column = (gint) x / column_width;
   minute = y / minute_height;
   minute = minute - (minute % 30);
 
-  self->selection_start = (column * MINUTES_PER_DAY + minute) / 30;
-  self->selection_end = self->selection_start;
+  self->selection.start = (column * MINUTES_PER_DAY + minute) / 30;
+  self->selection.end = self->selection.start;
 
-  gtk_widget_queue_draw (GTK_WIDGET (self));
+  gtk_widget_set_visible (self->selection.widget, TRUE);
 
   gtk_event_controller_set_propagation_phase (self->motion_controller, GTK_PHASE_BUBBLE);
 }
@@ -229,13 +240,13 @@ on_motion_controller_motion_cb (GtkEventControllerMotion *motion_controller,
   gint minute;
 
   minute_height = (gdouble) gtk_widget_get_height (GTK_WIDGET (self)) / MINUTES_PER_DAY;
-  column = self->selection_start * 30 / MINUTES_PER_DAY;
+  column = self->selection.start * 30 / MINUTES_PER_DAY;
   minute = y / minute_height;
   minute = minute - (minute % 30);
 
-  self->selection_end = (column * MINUTES_PER_DAY + minute) / 30;
+  self->selection.end = (column * MINUTES_PER_DAY + minute) / 30;
 
-  gtk_widget_queue_draw (GTK_WIDGET (self));
+  gtk_widget_queue_allocate (GTK_WIDGET (self));
 }
 
 static void
@@ -264,14 +275,14 @@ on_click_gesture_released_cb (GtkGestureClick *click_gesture,
   ltr = gtk_widget_get_direction (GTK_WIDGET (self)) != GTK_TEXT_DIR_RTL;
 
   minute_height = (gdouble) gtk_widget_get_height (GTK_WIDGET (self)) / MINUTES_PER_DAY;
-  column = self->selection_start * 30 / MINUTES_PER_DAY;
+  column = self->selection.start * 30 / MINUTES_PER_DAY;
   minute = y / minute_height;
   minute = minute - (minute % 30);
 
-  self->selection_end = (column * MINUTES_PER_DAY + minute) / 30;
+  self->selection.end = (column * MINUTES_PER_DAY + minute) / 30;
 
-  start_cell = self->selection_start;
-  end_cell = self->selection_end;
+  start_cell = self->selection.start;
+  end_cell = self->selection.end;
 
   if (start_cell > end_cell)
     {
@@ -280,7 +291,7 @@ on_click_gesture_released_cb (GtkGestureClick *click_gesture,
       start_cell = start_cell - end_cell;
     }
 
-  gtk_widget_queue_draw (GTK_WIDGET (self));
+  gtk_widget_queue_allocate (GTK_WIDGET (self));
 
   /* Fake the week view's event so we can control the X and Y values */
   weekview = gtk_widget_get_ancestor (GTK_WIDGET (self), GCAL_TYPE_WEEK_VIEW);
@@ -362,7 +373,7 @@ move_event_to_cell (GcalWeekGrid          *self,
 
   changed_event = gcal_event_new_from_event (event);
   week_start = gcal_date_time_get_start_of_week (self->active_date);
-  dnd_date = g_date_time_add_minutes (week_start, cell * 30);
+  dnd_date = gcal_date_time_add_floating_minutes (week_start, cell * 30);
 
   /*
    * Calculate the diff between the dropped cell and the event's start date,
@@ -442,30 +453,45 @@ on_drop_target_drop_cb (GtkDropTarget *drop_target,
   GCAL_RETURN (TRUE);
 }
 
+static GdkDragAction
+on_drop_target_enter_cb (GtkDropTarget *drop_target,
+                         gdouble        x,
+                         gdouble        y,
+                         GcalWeekGrid  *self)
+{
+
+  GCAL_ENTRY;
+
+  self->dnd.cell = get_dnd_cell (self, x, y);
+  gtk_widget_set_visible (self->dnd.widget, TRUE);
+
+  GCAL_RETURN (GDK_ACTION_COPY);
+}
+
 static void
 on_drop_target_leave_cb (GtkDropTarget *drop_target,
                          GcalWeekGrid  *self)
 {
   GCAL_ENTRY;
 
-  self->dnd_cell = -1;
-  gtk_widget_queue_draw (GTK_WIDGET (self));
+  self->dnd.cell = -1;
+  gtk_widget_set_visible (self->dnd.widget, FALSE);
 
   GCAL_EXIT;
 }
 
 static GdkDragAction
 on_drop_target_motion_cb (GtkDropTarget *drop_target,
-                         gdouble        x,
-                         gdouble        y,
-                         GcalWeekGrid  *self)
+                          gdouble        x,
+                          gdouble        y,
+                          GcalWeekGrid  *self)
 {
   GCAL_ENTRY;
 
-  self->dnd_cell = get_dnd_cell (self, x, y);
-  gtk_widget_queue_draw (GTK_WIDGET (self));
+  self->dnd.cell = get_dnd_cell (self, x, y);
+  gtk_widget_queue_allocate (GTK_WIDGET (self));
 
-  GCAL_RETURN (self->dnd_cell != -1 ? GDK_ACTION_COPY : 0);
+  GCAL_RETURN (GDK_ACTION_COPY);
 }
 
 static void
@@ -473,8 +499,10 @@ gcal_week_grid_dispose (GObject *object)
 {
   GcalWeekGrid *self = GCAL_WEEK_GRID (object);
 
+  g_clear_pointer (&self->dnd.widget, gtk_widget_unparent);
   g_clear_pointer (&self->events, gcal_range_tree_unref);
   g_clear_pointer (&self->now_strip, gtk_widget_unparent);
+  g_clear_pointer (&self->selection.widget, gtk_widget_unparent);
 
   G_OBJECT_CLASS (gcal_week_grid_parent_class)->dispose (object);
 }
@@ -534,55 +562,10 @@ gcal_week_grid_measure (GtkWidget      *widget,
                         gint           *minimum_baseline,
                         gint           *natural_baseline)
 {
-  g_autoptr (PangoLayout) layout = NULL;
-  PangoFontDescription *font_desc;
-  GtkStyleContext *context;
-  PangoContext *pango_context;
-  GtkBorder padding;
-  gint hours_12_height;
-  gint hours_24_height;
-  gint cell_height;
-  gint height;
-
-  if (orientation == GTK_ORIENTATION_HORIZONTAL)
-    {
-      if (minimum)
-        *minimum = 1;
-      if (natural)
-        *natural = 1;
-      return;
-    }
-
-  context = gtk_widget_get_style_context (widget);
-
-  gtk_style_context_save (context);
-  gtk_style_context_add_class (context, "hours");
-
-  gtk_style_context_get_padding (context, &padding);
-
-  pango_context = gtk_widget_get_pango_context (widget);
-  font_desc = pango_context_get_font_description (pango_context);
-
-  layout = pango_layout_new (pango_context);
-  pango_layout_set_font_description (layout, font_desc);
-
-  pango_layout_set_text (layout, _("00 AM"), -1);
-  pango_layout_get_pixel_size (layout, NULL, &hours_12_height);
-
-  pango_layout_set_text (layout, _("00:00"), -1);
-  pango_layout_get_pixel_size (layout, NULL, &hours_24_height);
-
-  cell_height = MAX (hours_12_height, hours_24_height) + padding.top + padding.bottom;
-  height = cell_height * 48;
-
-  gtk_style_context_restore (context);
-
-  /* Report the height */
   if (minimum)
-    *minimum = height;
-
+    *minimum = 1;
   if (natural)
-    *natural = height;
+    *natural = 1;
 }
 
 static void
@@ -590,97 +573,22 @@ gcal_week_grid_snapshot (GtkWidget   *widget,
                          GtkSnapshot *snapshot)
 {
   g_autoptr (GPtrArray) widgets = NULL;
-  GtkStyleContext *context;
-  GtkStateFlags state;
   GcalWeekGrid *self;
-  GtkBorder padding;
-  GdkRGBA color;
-  gdouble minutes_height;
-  gdouble x, column_width;
-  guint i;
   gint width, height;
 
   self = GCAL_WEEK_GRID (widget);
-  context = gtk_widget_get_style_context (widget);
-  state = gtk_widget_get_state_flags (widget);
-
-  gtk_style_context_save (context);
-  gtk_style_context_add_class (context, "lines");
-  gtk_style_context_get_color (context, &color);
-  gtk_style_context_get_padding (context, &padding);
-
   width = gtk_widget_get_width (widget);
   height = gtk_widget_get_height (widget);
-  column_width = width / 7.0;
-  minutes_height = (gdouble) height / MINUTES_PER_DAY;
+
+  gcal_week_view_common_snapshot_hour_lines (widget, snapshot, GTK_ORIENTATION_HORIZONTAL, width, height);
+  gcal_week_view_common_snapshot_hour_lines (widget, snapshot, GTK_ORIENTATION_VERTICAL, width, height);
 
   /* First, draw the selection */
-  if (self->selection_start != -1 && self->selection_end != -1)
-    {
-      gint selection_height;
-      gint column;
-      gint start;
-      gint end;
-
-      start = self->selection_start;
-      end = self->selection_end;
-
-      /* Swap cells if needed */
-      if (start > end)
-        {
-          start = start + end;
-          end = start - end;
-          start = start - end;
-        }
-
-      column = start * 30 / MINUTES_PER_DAY;
-      selection_height = (end - start + 1) * 30 * minutes_height;
-
-      x = column * column_width;
-
-      gtk_style_context_save (context);
-      gtk_style_context_set_state (context, state | GTK_STATE_FLAG_SELECTED);
-
-      gtk_snapshot_render_background (snapshot,
-                                      context,
-                                      ALIGNED (x),
-                                      round ((start * 30 % MINUTES_PER_DAY) * minutes_height),
-                                      column_width,
-                                      selection_height);
-
-      gtk_style_context_restore (context);
-    }
-
-  /* Drag and Drop highlight */
-  if (self->dnd_cell != -1)
-    {
-      gdouble cell_height;
-      gint column, row;
-
-      cell_height = minutes_height * 30;
-      column = self->dnd_cell / (MINUTES_PER_DAY / 30);
-      row = self->dnd_cell - column * 48;
-
-      gtk_style_context_save (context);
-      gtk_style_context_add_class (context, "dnd");
-
-      gtk_snapshot_render_background (snapshot,
-                                      context,
-                                      column * column_width,
-                                      row * cell_height,
-                                      column_width,
-                                      cell_height);
-
-      gtk_style_context_restore (context);
-    }
-
-  gcal_week_view_common_snapshot_hour_lines (widget, snapshot, GTK_ORIENTATION_HORIZONTAL, &color, width, height);
-  gcal_week_view_common_snapshot_hour_lines (widget, snapshot, GTK_ORIENTATION_VERTICAL, &color, width, height);
-
-  gtk_style_context_restore (context);
+  gtk_widget_snapshot_child (widget, self->selection.widget, snapshot);
+  gtk_widget_snapshot_child (widget, self->dnd.widget, snapshot);
 
   widgets = gcal_range_tree_get_all_data (self->events);
-  for (i = 0; i < widgets->len; i++)
+  for (guint i = 0; i < widgets->len; i++)
     {
       ChildData *child_data = g_ptr_array_index (widgets, i);
 
@@ -712,6 +620,70 @@ gcal_week_grid_size_allocate (GtkWidget *widget,
   minutes_height = (gdouble) height / MINUTES_PER_DAY;
   column_width = (gdouble) width / 7.0;
 
+  /* Selection */
+  if (gtk_widget_should_layout (self->selection.widget))
+    {
+      gint selection_height;
+      gint column;
+      gint start;
+      gint end;
+      gint y;
+
+      g_assert (self->selection.start != -1);
+      g_assert (self->selection.end != -1);
+
+      start = self->selection.start;
+      end = self->selection.end;
+
+      /* Swap cells if needed */
+      if (start > end)
+        {
+          start = start + end;
+          end = start - end;
+          start = start - end;
+        }
+
+      column = start * 30 / MINUTES_PER_DAY;
+
+#define Y_POSITION(cell_) (round (((cell_) * 30 % MINUTES_PER_DAY) * minutes_height))
+
+      x = column * column_width;
+      y = Y_POSITION (start);
+      selection_height = Y_POSITION (end + 1) - y;
+
+#undef Y_POSITION
+
+      gtk_widget_size_allocate (self->selection.widget,
+                                &(GtkAllocation) {
+                                  .x = x,
+                                  .y = y,
+                                  .width = column_width - 1,
+                                  .height = selection_height,
+                                },
+                                baseline);
+    }
+
+  if (gtk_widget_should_layout (self->dnd.widget))
+    {
+      gdouble cell_height;
+      gint column, row;
+
+      g_assert (self->dnd.cell != -1);
+
+      cell_height = minutes_height * 30;
+      column = self->dnd.cell / (MINUTES_PER_DAY / 30);
+      row = self->dnd.cell - column * 48;
+
+      gtk_widget_size_allocate (self->dnd.widget,
+                                &(GtkAllocation) {
+                                  .x = column * column_width,
+                                  .y = row * cell_height,
+                                  .width = column_width,
+                                  .height = cell_height,
+                                },
+                                baseline);
+    }
+
   /* Temporary range tree to hold positioned events' indexes */
   overlaps = gcal_range_tree_new ();
 
@@ -874,9 +846,16 @@ gcal_week_grid_init (GcalWeekGrid *self)
   GtkDropTarget *drop_target;
   GtkGesture *click_gesture;
 
-  self->selection_start = -1;
-  self->selection_end = -1;
-  self->dnd_cell = -1;
+  self->selection.start = -1;
+  self->selection.end = -1;
+  self->selection.widget = gcal_create_selection_widget ();
+  gtk_widget_set_visible (self->selection.widget, FALSE);
+  gtk_widget_set_parent (self->selection.widget, GTK_WIDGET (self));
+
+  self->dnd.cell = -1;
+  self->dnd.widget = gcal_create_drop_target_widget ();
+  gtk_widget_set_visible (self->dnd.widget, FALSE);
+  gtk_widget_set_parent (self->dnd.widget, GTK_WIDGET (self));
 
   self->events = gcal_range_tree_new_with_free_func (child_data_free);
 
@@ -898,6 +877,7 @@ gcal_week_grid_init (GcalWeekGrid *self)
 
   drop_target = gtk_drop_target_new (GCAL_TYPE_EVENT_WIDGET, GDK_ACTION_COPY);
   g_signal_connect (drop_target, "drop", G_CALLBACK (on_drop_target_drop_cb), self);
+  g_signal_connect (drop_target, "enter", G_CALLBACK (on_drop_target_enter_cb), self);
   g_signal_connect (drop_target, "leave", G_CALLBACK (on_drop_target_leave_cb), self);
   g_signal_connect (drop_target, "motion", G_CALLBACK (on_drop_target_motion_cb), self);
   gtk_widget_add_controller (GTK_WIDGET (self), GTK_EVENT_CONTROLLER (drop_target));
@@ -991,10 +971,9 @@ gcal_week_grid_clear_marks (GcalWeekGrid *self)
 {
   g_return_if_fail (GCAL_IS_WEEK_GRID (self));
 
-  self->selection_start = -1;
-  self->selection_end = -1;
-
-  gtk_widget_queue_draw (GTK_WIDGET (self));
+  self->selection.start = -1;
+  self->selection.end = -1;
+  gtk_widget_set_visible (self->selection.widget, FALSE);
 }
 
 void
