@@ -199,9 +199,9 @@ is_authentication_error (gint code)
 {
   switch (code)
     {
+    /* Only HTTP 401 and 407 errors are actual prompts for credentials. 403, 405, etc. are not. */
     case SOUP_STATUS_UNAUTHORIZED:
-    case SOUP_STATUS_FORBIDDEN:
-    case SOUP_STATUS_METHOD_NOT_ALLOWED:
+    case SOUP_STATUS_PROXY_UNAUTHORIZED:
       return TRUE;
     }
 
@@ -281,7 +281,7 @@ discover_file_in_thread (DiscovererData  *data,
   uri_str = g_uri_to_string_partial (guri, G_URI_HIDE_PASSWORD);
   GCAL_TRACE_MSG ("Creating request for %s", uri_str);
 
-  session = soup_session_new_with_options ("timeout", 10, NULL);
+  session = gcal_create_soup_session ();
 
   message = soup_message_new_from_uri ("GET", guri);
   g_signal_connect (message, "authenticate", G_CALLBACK (on_soup_message_authenticate_cb), data);
@@ -371,6 +371,12 @@ discover_webdav_in_thread (DiscovererData  *data,
 
   if (local_error)
     {
+      g_debug ("Encountered an error in %s (from %s), code %d: '%s'\n",
+               G_STRFUNC,
+               g_quark_to_string (local_error->domain),
+               local_error->code,
+               local_error->message);
+
       if (local_error->domain == E_SOUP_SESSION_ERROR &&
           is_authentication_error (local_error->code))
         {
